@@ -580,7 +580,7 @@ static void execute_program(char *op,
 
 		debug("%s %s\n", pipeit ? "PipeThru" : "Run", prog);
 		for (ap = argv; *ap; ap++)
-			debug("- argv[%zd] = \"%s\"\n", ap - argv, *ap);
+			debug("- argv[%td] = \"%s\"\n", ap - argv, *ap);
 	}
 
 	/* become the same UID/GID as the key requesting process */
@@ -709,11 +709,6 @@ static void pipe_to_program(char *op,
 		if (tmp < 0)
 			error("select failed: %m\n");
 
-		debug("select -> %d r=%x w=%x\n",
-		      tmp,
-		      *(unsigned *) (void *) &rfds,
-		      *(unsigned *) (void *) &wfds);
-
 		if (TOSTDIN != -1 && FD_ISSET(TOSTDIN, &wfds)) {
 			tmp = write(TOSTDIN, pc, ninfo);
 			if (tmp < 0) {
@@ -843,7 +838,7 @@ static void pipe_to_program(char *op,
 	}
 
 	/* attempt to instantiate the key */
-	debug("instantiate with %zd bytes\n", pp - payload);
+	debug("instantiate with %td bytes\n", pp - payload);
 
 	if (keyctl_instantiate(key, payload, pp - payload, 0) < 0)
 		error("instantiate key failed: %m\n");
